@@ -25,13 +25,13 @@ import numpy as np
 
 from spatialmath.base import argcheck
 from spatialmath import base as tr
-from spatialmath.super_pose import SMPose
+from spatialmath.baseposematrix import BasePoseMatrix
 import spatialmath.pose3d as p3
 
 # ============================== SO2 =====================================#
 
 
-class SO2(SMPose):
+class SO2(BasePoseMatrix):
     """
     SO(2) matrix class
 
@@ -74,7 +74,10 @@ class SO2(SMPose):
         """
         super().__init__()
         
-        if  super().arghandler(arg, check=check):
+        if isinstance(arg, SE2):
+            self.data = [tr.t2r(x) for x in arg.data]
+
+        elif  super().arghandler(arg, check=check):
             return
 
         elif argcheck.isscalar(arg):
@@ -288,6 +291,9 @@ class SE2(SO2):
             if super().arghandler(x, check=check):
                 return
 
+            if isinstance(x, SO2):
+                self.data = [tr.r2t(_x) for _x in x.data]
+
             elif argcheck.isscalar(x):
                 self.data = [tr.trot2(x, unit=unit)]
             elif len(x) == 2:
