@@ -26,13 +26,13 @@ To use::
 import numpy as np
 
 from spatialmath import base
-from spatialmath.super_pose import SMPose
+from spatialmath.baseposematrix import BasePoseMatrix
 
 
 # ============================== SO3 =====================================#
 
 
-class SO3(SMPose):  
+class SO3(BasePoseMatrix):  
     """
     SO(3) matrix class
 
@@ -68,7 +68,10 @@ class SO3(SMPose):
         """
         super().__init__()
         
-        if not super().arghandler(arg, check=check):
+        if isinstance(arg, SE3):
+            self.data = [base.t2r(x) for x in arg.data]
+
+        elif not super().arghandler(arg, check=check):
             raise ValueError('bad argument to constructor')
 
     @staticmethod
@@ -619,22 +622,23 @@ class SO3(SMPose):
         else:
             return cls(base.trexp(S, check=check), check=False)
 
-    def angdist(self, other, metric=3):
+    def angdist(self, other, metric=6):
         r"""
-        Angular distance metric between unit quaternions
+        Angular distance metric between rotations
 
-        :param other: second unit quaternion
-        :type other: UnitQuaternion instance
-        :param metric: metric, default is 3
+        :param other: second rotation
+        :type other: SO3 instance
+        :param metric: metric, default is 6
         :type metric: int
-        :raises TypeError: if other is not a UnitQuaternion
+        :raises TypeError: if other is not an SO3
         :return: angle in radians
-        :rtype: float
+        :rtype: float or ndarray
 
-        ``q1.angdist(q2)`` is the geodesic norm, or geodesic distance between two
-        unit quaternions.  We can consider it as the angle between two quaternions.
+        ``R1.angdist(R2)`` is the geodesic norm, or geodesic distance between two
+        rotations.
 
-        Several metrics are supported:
+        Several metrics are supported, the first 5 are computed after conversion
+        to unit quaternions.
 
         ======   ===============================================================
         Metric   Details
@@ -644,6 +648,8 @@ class SO3(SMPose):
         2        :math:`\cos^{-1} | \q_1 \bullet \q_2 | \in [0, \pi/2]`
         3        :math:`2 \tan^{-1} \| \q_1 - \q_2\| / \|\q_1 + \q_2\| \in [0, \pi/2]`
         4        :math:`\cos^{-1} \left( 2 (\q_1 \bullet \q_2)^2 - 1\right) \in [0, 1]`
+        5        :math:`\|I - \mat{R}_1 \mat{R}_2^T\| \in [0, 2]`
+        6        :math:`\|\log \mat{R}_1 \mat{R}_2^T\| \in [0, \pi]`
         ======   ===============================================================
 
         Example:
@@ -651,22 +657,37 @@ class SO3(SMPose):
         .. runblock:: pycon
 
             >>> from spatialmath import UnitQuaternion
-            >>> q1 = UnitQuaternion.Rx(0.3)
-            >>> q2 = UnitQuaternion.Ry(0.3)
-            >>> print(q1.angdist(q1))
-            >>> print(q1.angdist(q2))
+            >>> R1 = SO3.Rx(0.3)
+            >>> R2 = SO3.Ry(0.3)
+            >>> print(R1.angdist(R1))
+            >>> print(R1.angdist(R2))
 
         .. note::
             - metrics 1, 2, 4 can throw ValueError "math domain error" due to
               numeric errors which push the argument of ``acos()`` marginally
               outside its domain [0, 1].
             - metrics 2 and 3 are equivalent, but 3 is more robust
-            - SMTB-MATLAB uses metric 3 for UnitQuaternion.angle()
-            - MATLAB's quaternion.dist() uses metric 4
-        """
-        from spatialmath.quaternion import UnitQuaternion
 
-        return UnitQuaternion(self).angdist(UnitQuaternion(other), metric=metric)
+        :seealso: :func:`UnitQuaternion.angdist`
+        """
+
+        if metric < 5:
+            from spatialmath.quaternion import UnitQuaternion
+
+            return UnitQuaternion(self).angdist(UnitQuaternion(other), metric=metric)
+
+        elif metric == 5:
+            op = lambda R1, R2: np.linalg.norm(np.eye(3) - R1 @ R2.T)
+        elif metric == 6:
+            op = lambda R1, R2: base.norm(base.trlog(R1 @ R2.T, twist=True))
+        else:
+            raise ValueError('unknown metric')
+        
+        ad = self._op2(other, op)
+        if isinstance(ad, list):
+            return np.array(ad)
+        else:
+            return ad
 
 # ============================== SE3 =====================================#
 
@@ -689,21 +710,23 @@ class SE3(SO3):
 
         :rtype: SE3 instance
 
-        There are multiple call signatures:
+        There are multiple call signatures that return an ``SE3`` instance
+        with one or more values.
 
-        - ``SE3()`` is an ``SE3`` instance with one value  -- a 4x4 identity
-          matrix which corresponds to a null motion.
+        - ``SE3()`` null motion, value is the identity matrix.
         - ``SE3(x, y, z)`` is a pure translation of (x,y,z)
-        - ``SE3(T)`` is an ``SE3`` instance with the value ``T`` which is a 4x4
-          numpy array representing an SE(3) matrix.  If ``check`` is ``True``
-          check the matrix belongs to SE(3).
-        - ``SE3(X)`` is an ``SE3`` instance with the same value as ``X``, ie.
-          a copy.
-        - ``SE3([T1, T2, ... TN])`` is an ``SE3`` instance with ``N`` values
+        - ``SE3(T)``  where ``T`` is a 4x4 Numpy  array representing an SE(3)
+          matrix.  If ``check`` is ``True`` check the matrix belongs to SE(3).
+        - ``SE3([T1, T2, ... TN])`` has ``N`` values
           given by the elements ``Ti`` each of which is a 4x4 NumPy array
           representing an SE(3) matrix. If ``check`` is ``True`` check the
           matrix belongs to SE(3).
-        - ``SE3([X1, X2, ... XN])`` is an ``SE3`` instance with ``N`` values
+        - ``SE3(X)`` where ``X`` is:
+          -  ``SE3`` is a copy of ``X``
+          -  ``SO3`` is the rotation of ``X`` with zero translation
+          -  ``SE2`` is the z-axis rotation and x- and y-axis translation of
+             ``X``
+        - ``SE3([X1, X2, ... XN])`` has ``N`` values
           given by the elements ``Xi`` each of which is an SE3 instance.
         
         :SymPy: supported
@@ -713,6 +736,16 @@ class SE3(SO3):
 
             if super().arghandler(x, check=check):
                 return
+            elif isinstance(x, SO3):
+                self.data = [base.r2t(_x) for _x in x.data]
+            elif type(x).__name__ == 'SE2':
+                def convert(x):
+                    # convert SE(2) to SE(3)
+                    out = np.identity(4, dtype=x.dtype)
+                    out[:2,:2] = x[:2,:2]
+                    out[:2,3] = x[:2,2]
+                    return out
+                self.data = [convert(_x) for _x in x.data]
             elif base.isvector(x, 3):
                 # SE3( [x, y, z] )
                 self.data = [base.transl(x)]
@@ -896,7 +929,7 @@ class SE3(SO3):
         """
         return base.tr2jac(self.A)
 
-    def Twist3(self):
+    def twist(self):
         """
         SE(3) as twist
 
@@ -906,7 +939,7 @@ class SE3(SO3):
         Example::
 
             >>> x = SE3(1,2,3)
-            >>> x.Twist3()
+            >>> x.twist()
             Twist3([1, 2, 3, 0, 0, 0])
 
         :seealso: :func:`spatialmath.twist.Twist3`
@@ -1425,31 +1458,58 @@ class SE3(SO3):
         return cls([base.transl(0, 0, _z) for _z in base.getvector(z)], check=False)
 
     @classmethod
-    def SO3(cls, R, t=None, check=True):
+    def Rt(cls, R, t, check=True):
+        """
+        Create an SE(3) from rotation and translation
+
+        :param R: rotation
+        :type R: SO3 or ndarray(3,3)
+        :param t: translation
+        :type t: array_like(3)
+        :param check: check rotation validity, defaults to True
+        :type check: bool, optional
+        :raises ValueError: bad rotation matrix
+        :return: SE(3) matrix
+        :rtype: SE3 instance
+        """
         if isinstance(R, SO3):
             R = R.A
         elif base.isrot(R, check=check):
             pass
         else:
             raise ValueError('expecting SO3 or rotation matrix')
-        if t is None:
-            return cls(base.r2t(R))
-        else:
-            return cls(base.rt2tr(R, t))
+
+        return cls(base.rt2tr(R, t))
+
+    # @classmethod
+    # def SO3(cls, R, t=None, check=True):
+    #     if isinstance(R, SO3):
+    #         R = R.A
+    #     elif base.isrot(R, check=check):
+    #         pass
+    #     else:
+    #         raise ValueError('expecting SO3 or rotation matrix')
+    #     if t is None:
+    #         return cls(base.r2t(R))
+    #     else:
+    #         return cls(base.rt2tr(R, t))
 
 if __name__ == '__main__':   # pragma: no cover
 
     import pathlib
 
+    a = SE3(1,2,3)
+    b = SO3(a)
+    print(b)
+
     a = SO3.RPY([.1, .2, .3])
-    print(a)
-    a = SO3.RPY(.1, .2, .3)
-    print(a)
+    b = SE3(a)
+    print(b)
+
+    from spatialmath import SE2
+    a = SE2(1,2,.4)
+    b = SE3(a)
+    print(b)
 
-    SE3._bgcolor = 'yellow'
-    # SE3._format = '{:< 6.2f}'
-    SE3._supress_small = False
-    a = SE3.Rx(np.pi/2)
-    print(a)
 
     exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_pose3d.py").read())  # pylint: disable=exec-used
