@@ -16,12 +16,12 @@ A set of cooperating classes to support Featherstone's spatial vector formalism
 
 from abc import abstractmethod
 import numpy as np
-from spatialmath.smuserlist import SMUserList
+from spatialmath.baseposelist import BasePoseList
 from spatialmath import base
 from spatialmath.pose3d import SE3
 from spatialmath.twist import Twist3
 
-class SpatialVector(SMUserList):
+class SpatialVector(BasePoseList):
     """
     Spatial 6-vector abstract superclass
 
@@ -467,7 +467,7 @@ class SpatialMomentum(SpatialF6):
 
 # ------------------------------------------------------------------------- #
 
-class SpatialInertia(SMUserList):
+class SpatialInertia(BasePoseList):
     """
     Spatial inertia class
 
@@ -500,6 +500,8 @@ class SpatialInertia(SMUserList):
 
         - ``SpatialInertia(I)`` is a spatial inertia object with a value equal
           to ``I`` (6x6).
+
+        :SymPy: supported
         """
         super().__init__()
 
@@ -515,9 +517,10 @@ class SpatialInertia(SMUserList):
             else:
                 I = base.getmatrix(I, (3,3))
             C = base.skew(r)
+            M = np.diag((m,) * 3)  # sym friendly
             I = np.block([
-                    [m * np.eye(3), m * C.T],
-                    [m * C,         I + m * C @ C.T]
+                    [M,      m * C.T],
+                    [m * C,  I + m * C @ C.T]
                     ])
         else:
             raise ValueError('bad values')
